@@ -43,6 +43,9 @@ class BatchInfo(object):
     )  # type: Optional[Text]
     id = attr.ib(metadata={JsonInclude.THIS: True})  # type: Text
     notify_on_completion = attr.ib(metadata={JsonInclude.NON_NONE: True})  # type: bool
+    properties = attr.ib(
+        metadata={JsonInclude.NON_NONE: True}
+    )  # type: List[Dict[Text,Text]]
 
     def __init__(self, name=None, started_at=None, batch_sequence_name=None):
         # type: (Optional[Text], Optional[datetime], Optional[Text]) -> None
@@ -57,6 +60,7 @@ class BatchInfo(object):
         self.notify_on_completion = str2bool(
             get_env_with_prefix("APPLITOOLS_BATCH_NOTIFY")
         )  # type: bool
+        self.properties = []  # type: List[Dict[Text,Text]]
 
         if name:
             self.name = name
@@ -71,50 +75,114 @@ class BatchInfo(object):
         self.id = str(id)
         return self
 
+    def add_property(self, name, value):
+        # type: (Text, Text) -> BatchInfo
+        """
+        Associates a key/value pair with the Batch. This can be used later for filtering.
+        :param name: (string) The property name.
+        :param value: (string) The property value
+        """
+        self.properties.append({"name": name, "value": value})
+        return self
+
+    def clear_properties(self):
+        # type: () -> BatchInfo
+        """
+        Clears the list of Batch properties.
+        """
+        del self.properties[:]
+        return self
+
 
 @attr.s
 class Configuration(object):
-    batch = attr.ib(factory=BatchInfo)  # type: BatchInfo
+    batch = attr.ib(
+        metadata={JsonInclude.NON_NONE: True}, factory=BatchInfo
+    )  # type: BatchInfo
     branch_name = attr.ib(
-        factory=lambda: get_env_with_prefix("APPLITOOLS_BRANCH", None)
+        metadata={JsonInclude.NON_NONE: True},
+        factory=lambda: get_env_with_prefix("APPLITOOLS_BRANCH", None),
     )  # type: Optional[Text]
     parent_branch_name = attr.ib(
-        factory=lambda: get_env_with_prefix("APPLITOOLS_PARENT_BRANCH", None)
+        metadata={JsonInclude.NON_NONE: True},
+        factory=lambda: get_env_with_prefix("APPLITOOLS_PARENT_BRANCH", None),
     )  # type: Optional[Text]
     baseline_branch_name = attr.ib(
-        factory=lambda: get_env_with_prefix("APPLITOOLS_BASELINE_BRANCH", None)
+        metadata={JsonInclude.NON_NONE: True},
+        factory=lambda: get_env_with_prefix("APPLITOOLS_BASELINE_BRANCH", None),
+    )  # type: Optional[Text]
+    agent_id = attr.ib(
+        metadata={JsonInclude.NON_NONE: True}, default=None
+    )  # type: Optional[Text]
+    baseline_env_name = attr.ib(
+        metadata={JsonInclude.NON_NONE: True}, default=None
+    )  # type: Optional[Text]
+    environment_name = attr.ib(
+        metadata={JsonInclude.NON_NONE: True}, default=None
+    )  # type: Optional[Text]
+    save_diffs = attr.ib(
+        metadata={JsonInclude.NON_NONE: True}, default=None
+    )  # type: bool
+    app_name = attr.ib(
+        metadata={JsonInclude.NON_NONE: True}, default=None
+    )  # type: Optional[Text]
+    test_name = attr.ib(
+        metadata={JsonInclude.NON_NONE: True}, default=None
     )  # type: Optional[Text]
-    agent_id = attr.ib(default=None)  # type: Optional[Text]
-    baseline_env_name = attr.ib(default=None)  # type: Optional[Text]
-    environment_name = attr.ib(default=None)  # type: Optional[Text]
-    save_diffs = attr.ib(default=None)  # type: bool
-    app_name = attr.ib(default=None)  # type: Optional[Text]
-    test_name = attr.ib(default=None)  # type: Optional[Text]
     viewport_size = attr.ib(
-        default=None, converter=attr.converters.optional(RectangleSize.from_)
+        metadata={JsonInclude.NON_NONE: True},
+        default=None,
+        converter=attr.converters.optional(RectangleSize.from_),
     )  # type: Optional[RectangleSize]
-    session_type = attr.ib(default=SessionType.SEQUENTIAL)  # type: SessionType
-    host_app = attr.ib(default=None)  # type: Optional[Text]
-    host_os = attr.ib(default=None)  # type: Optional[Text]
-    properties = attr.ib(factory=list)  # type: List[Dict[Text, Text]]
-    match_timeout = attr.ib(default=DEFAULT_MATCH_TIMEOUT_MS)  # type: int # ms
-    is_disabled = attr.ib(default=False)  # type: bool
-    save_new_tests = attr.ib(default=True)  # type: bool
-    save_failed_tests = attr.ib(default=False)  # type: bool
-    failure_reports = attr.ib(default=FailureReports.ON_CLOSE)  # type: FailureReports
-    send_dom = attr.ib(default=True)  # type: bool
+    session_type = attr.ib(
+        metadata={JsonInclude.NON_NONE: True}, default=SessionType.SEQUENTIAL
+    )  # type: SessionType
+    host_app = attr.ib(
+        metadata={JsonInclude.NON_NONE: True}, default=None
+    )  # type: Optional[Text]
+    host_os = attr.ib(
+        metadata={JsonInclude.NON_NONE: True}, default=None
+    )  # type: Optional[Text]
+    properties = attr.ib(
+        metadata={JsonInclude.NON_NONE: True}, factory=list
+    )  # type: List[Dict[Text, Text]]
+    match_timeout = attr.ib(
+        metadata={JsonInclude.NON_NONE: True}, default=DEFAULT_MATCH_TIMEOUT_MS
+    )  # type: int # ms
+    is_disabled = attr.ib(
+        metadata={JsonInclude.NON_NONE: True}, default=False
+    )  # type: bool
+    save_new_tests = attr.ib(
+        metadata={JsonInclude.NON_NONE: True}, default=True
+    )  # type: bool
+    save_failed_tests = attr.ib(
+        metadata={JsonInclude.NON_NONE: True}, default=False
+    )  # type: bool
+    failure_reports = attr.ib(
+        metadata={JsonInclude.NON_NONE: True}, default=FailureReports.ON_CLOSE
+    )  # type: FailureReports
+    send_dom = attr.ib(
+        metadata={JsonInclude.NON_NONE: True}, default=True
+    )  # type: bool
     default_match_settings = attr.ib(
-        factory=ImageMatchSettings
+        metadata={JsonInclude.NON_NONE: True}, factory=ImageMatchSettings
     )  # type: ImageMatchSettings
-    stitch_overlap = attr.ib(default=5)  # type: int
+    stitch_overlap = attr.ib(
+        metadata={JsonInclude.NON_NONE: True}, default=5
+    )  # type: int
     api_key = attr.ib(
         factory=lambda: get_env_with_prefix("APPLITOOLS_API_KEY", None)
     )  # type: Optional[Text]
     server_url = attr.ib(
-        factory=lambda: get_env_with_prefix("APPLITOOLS_SERVER_URL", DEFAULT_SERVER_URL)
+        metadata={JsonInclude.NON_NONE: True},
+        factory=lambda: get_env_with_prefix(
+            "APPLITOOLS_SERVER_URL", DEFAULT_SERVER_URL
+        ),
     )  # type: Text
     _timeout = attr.ib(default=DEFAULT_SERVER_REQUEST_TIMEOUT_MS)  # type: int # ms
-    features = attr.ib(factory=set)  # type: Set[Feature]
+    features = attr.ib(
+        metadata={JsonInclude.NON_NONE: True}, factory=set
+    )  # type: Set[Feature]
 
     @property
     def enable_patterns(self):
@@ -348,10 +416,11 @@ class Configuration(object):
         return self.send_dom
 
     def clone(self):
-        # type: () -> Configuration
+        # type: () -> Self
         # TODO: Remove this huck when get rid of Python2
         # deepcopy on python 2 raise an exception so construct manually
         conf = copy(self)
+        conf.batch = deepcopy(conf.batch)
         conf.viewport_size = copy(conf.viewport_size)
         conf.properties = deepcopy(conf.properties)
         conf.default_match_settings = deepcopy(conf.default_match_settings)
@@ -359,7 +428,7 @@ class Configuration(object):
         return conf
 
     def add_property(self, name, value):
-        # type: (Text, Text) -> None
+        # type: (Text, Text) -> Self
         """
         Associates a key/value pair with the test. This can be used later for filtering.
         :param name: (string) The property name.
@@ -369,6 +438,7 @@ class Configuration(object):
         return self
 
     def clear_properties(self):
+        # type: () -> Self
         """
         Clears the list of custom properties.
         """
