@@ -78,6 +78,26 @@ class RectangleSize(DictAccessMixin):
         # type: (Union[RectangleSize, Dict]) -> bool
         return self.width == other["width"] and self.height == other["height"]
 
+    def __ne__(self, other):
+        # type: (Union[RectangleSize, Dict]) -> bool
+        return self.width != other["width"] or self.height != other["height"]
+
+    def __add__(self, other):
+        # type: (Union[RectangleSize, Dict]) -> RectangleSize
+        return RectangleSize(self.width + other["width"], self.height + other["height"])
+
+    def __radd__(self, other):
+        # type: (Union[RectangleSize, Dict]) -> RectangleSize
+        return RectangleSize(self.width + other["width"], self.height + other["height"])
+
+    def __sub__(self, other):
+        # type: (Union[RectangleSize, Dict]) -> RectangleSize
+        return RectangleSize(self.width - other["width"], self.height - other["height"])
+
+    def __rsub__(self, other):
+        # type: (Union[RectangleSize, Dict]) -> RectangleSize
+        return RectangleSize(other["width"] - self.width, other["height"] - self.height)
+
     def scale(self, scale_ratio):
         # type: (float) -> RectangleSize
         """Get a scaled version of the current size.
